from django import forms
from . import consts
from . import tools


class Log(forms.Form):
    ACTION_CHOICES = [('', '')] + list(consts.ACTION_CHOICES)
    LOG_LEVEL_CHOICES = [('', '')] + list(consts.LOG_LEVEL_CHOICES)

    datetime_from = forms.DateTimeField()
    datetime_to = forms.DateTimeField()

    action = forms.MultipleChoiceField(required=False, choices=consts.ACTION_CHOICES)
    level = forms.MultipleChoiceField(required=False, choices=consts.LOG_LEVEL_CHOICES)
    object_name = forms.MultipleChoiceField(required=False, choices=tools.get_models_choices())
    message = forms.CharField(required=False)
    username = forms.CharField(required=False)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2017-06-24 14:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('action', models.CharField(choices=[('', ''), ('created', 'created'), ('updated', 'updated'), ('deleted', 'deleted')], default='', max_length=10)),
                ('message', models.CharField(max_length=255)),
                ('func_name', models.CharField(max_length=255)),
                ('level', models.CharField(choices=[('', ''), ('CRITICAL', 'CRITICAL'), ('ERROR', 'ERROR'), ('WARNING', 'WARNING'), ('INFO', 'INFO'), ('DEBUG', 'DEBUG'), ('NOTSET', 'NOTSET')], default='NOTSET', max_length=10)),
                ('http_general', models.TextField(blank=True)),
                ('http_request_get', models.TextField(blank=True)),
                ('http_request_post', models.TextField(blank=True)),
                ('http_referrer', models.CharField(blank=True, max_length=255)),
                ('user_id', models.IntegerField(db_index=True, null=True)),
                ('username', models.CharField(blank=True, db_index=True, max_length=255)),
                ('object_name', models.CharField(blank=True, db_index=True, max_length=255)),
                ('object_id', models.IntegerField(db_index=True, null=True)),
                ('object_data', models.TextField(blank=True)),
                ('extra', models.TextField(blank=True)),
                ('dc', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-06-24 19:13
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sw_logger', '0002_auto_20170624_1618'),
    ]

    operations = [
        migrations.RenameField(
            model_name='log',
            old_name='dc',
            new_name='created',
        ),
    ]



from django.views.generic import TemplateView
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger

from . import models
from . import forms
from . import filters
from . import consts


class Log(TemplateView):
    template_name = None    # must be specified by
    model = models.Log
    form_class = forms.Log
    filter_class = filters.Log
    paginate_by = 30

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)

        qs = self.get_queryset()
        context['page'] = self._get_page(qs)
        context['object_list'] = qs

        context['LOG_LEVEL_CRITICAL'] = consts.LOG_LEVEL_CRITICAL
        context['LOG_LEVEL_ERROR'] = consts.LOG_LEVEL_ERROR
        context['LOG_LEVEL_WARNING'] = consts.LOG_LEVEL_WARNING
        context['LOG_LEVEL_INFO'] = consts.LOG_LEVEL_INFO
        context['LOG_LEVEL_DEBUG'] = consts.LOG_LEVEL_DEBUG
        context['LOG_LEVEL_NOTSET'] = consts.LOG_LEVEL_NOTSET

        form = self.get_form()
        form.is_valid()
        context['form'] = form

        return context

    def get_form(self):
        return self.form_class(self.request.GET or None)

    def get_queryset(self):
        form = self.get_form()
        if form.is_valid():
            params = form.cleaned_data
            qs = self.model.objects.all()
            qs = self.filter_class(params, qs).qs
            return qs
        else:
            return self.model.objects.none()

    def _get_page(self, qs):
        paginator = Paginator(qs, self.paginate_by)

        page_num = self.request.GET.get('page')
        try:
            page = paginator.page(page_num)
        except PageNotAnInteger:
            page = paginator.page(1)
        except EmptyPage:
            page = paginator.page(paginator.num_pages)

        return page

